# CHANGELOG

<!-- version list -->

## v1.1.2 (2026-03-21)

### Bug Fixes

- Another dummy commit to check if the CD worklow works
  ([`2012f41`](https://github.com/nachollorca/lmdk/commit/2012f41f1ea4ee6e1b89870cc492777ada679840))


## v1.1.1 (2026-03-21)

### Bug Fixes

- Dummy commit to check if the CD worklow works
  ([`cc48cd1`](https://github.com/nachollorca/lmdk/commit/cc48cd16a16758cc50c666d6bdad2e7950a9ecb3))


## v1.1.0 (2026-03-21)

### Code Style

- Add some better type hinting
  ([`4bfd2ad`](https://github.com/nachollorca/lmdk/commit/4bfd2ad7b6aee2281f63ff4964946b789529de18))

### Continuous Integration

- Add token to fix semantic release
  ([`8e75a2e`](https://github.com/nachollorca/lmdk/commit/8e75a2e8ebb8ba8d3e1376e87ef36f5cb8bc1668))

- Make workflows more efficient, ignore verbi-pypi
  ([`8730f76`](https://github.com/nachollorca/lmdk/commit/8730f7610ae4055d2e9e1bb9fbab909b8049bb6e))

- Try to fix the release workflow
  ([`d39c6d7`](https://github.com/nachollorca/lmdk/commit/d39c6d7ba4eb641d2d6ed8ca792b62d42f3ab40a))

- Upgrade python-semantic-release and publish-action versions
  ([`ec6d890`](https://github.com/nachollorca/lmdk/commit/ec6d8909ed3d2fbb1b852fdb9134e5cbf0725c4c))

### Documentation

- Extend readme
  ([`658d871`](https://github.com/nachollorca/lmdk/commit/658d871473acc513c4a139cae7d23538ac3483b6))

- Extend readme and add license
  ([`cd87649`](https://github.com/nachollorca/lmdk/commit/cd87649460a8f96cc3e20be086edf7b9d234e1ab))

- Little readme change
  ([`e635b5f`](https://github.com/nachollorca/lmdk/commit/e635b5fadc071ca224fd0e52bc43acb705ee03ed))

- Make a better docstring for the Provider class
  ([`19b4d9b`](https://github.com/nachollorca/lmdk/commit/19b4d9bb4f9b0d0d00e91b688f82cba91f9e4ac4))

- Make expanders in the usage
  ([`9e85aef`](https://github.com/nachollorca/lmdk/commit/9e85aef11bc5ccda00c1e592524e9e9d65703545))

- TOC newline
  ([`7a53374`](https://github.com/nachollorca/lmdk/commit/7a533746a0e7b3f2c8afbba791416498f91a1ee1))

### Features

- Add example file, unify exception handling and solve typing quirks
  ([`cf9f0e0`](https://github.com/nachollorca/lmdk/commit/cf9f0e03ce885342c9941aa4ae1a09399f5a4d62))

- Add more errors
  ([`2dab995`](https://github.com/nachollorca/lmdk/commit/2dab995829ebac66ef3bbc4b90c3120a0ce5bbfa))

- Add structured output and steram to mistral provider
  ([`b90d0f4`](https://github.com/nachollorca/lmdk/commit/b90d0f40b34099389b930970089b77796771c76d))

- Add vertex provider
  ([`72dcd45`](https://github.com/nachollorca/lmdk/commit/72dcd4514a9d27d7e149400c02ed3da71fe82293))

- Add vertex provider
  ([`6715367`](https://github.com/nachollorca/lmdk/commit/6715367cc74b11ef93abd38a47ac15c491a86adb))

- Make example script runnable
  ([`544a3b3`](https://github.com/nachollorca/lmdk/commit/544a3b3bcea49c060773ad57ea50f7a1ba31b8d9))

### Refactoring

- From lmtk to lmdk
  ([`2dec044`](https://github.com/nachollorca/lmdk/commit/2dec0442c3ac2cd225764f26fd40c8dd37b6ea5d))

- Move RawResponse to datatypes
  ([`ed64469`](https://github.com/nachollorca/lmdk/commit/ed64469430c11dfb273e7123cf1d45d31f0305d7))

- Remove duplication in payload building
  ([`164bb9b`](https://github.com/nachollorca/lmdk/commit/164bb9baa145f24c8df5e4fd582295755d6c168a))

- Rename get_response to complete and get_response_batch to complete_batch
  ([`d8665f3`](https://github.com/nachollorca/lmdk/commit/d8665f3ec223471f9728473d79ba1fd0c7a1f3b7))


## v1.0.0 (2026-03-17)

- Initial Release
